========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/sahara-image-elements.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

Sahara image elements project
==============================

This repo is a place for Sahara-related for diskimage-builder elements.

Script for creating Fedora and Ubuntu cloud images with our elements and default parameters. You should only need to run this command:

.. sourcecode:: bash

    tox -e venv -- sahara-image-create

Note: More information about script `diskimage-create <https://git.openstack.org/cgit/openstack/sahara-image-elements/tree/diskimage-create/README.rst>`_
